==> easyviper.core.impl-1.0-sources.jar: com/ebmwebsourcing/easyviper/tools/SysoutSenderImpl.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.tools;

import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.extensions.Membrane;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.env.ExternalContext;
import com.ebmwebsourcing.easyviper.core.api.env.Sender;
import com.ebmwebsourcing.easyviper.core.api.soa.Endpoint;
import com.ebmwebsourcing.easyviper.core.api.soa.message.ExternalMessage;
import com.ebmwebsourcing.easyviper.core.api.soa.message.InternalMessage;
import com.ebmwebsourcing.easyviper.core.impl.env.AbstractSenderImpl;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@org.objectweb.fractal.fraclet.annotations.Component
@Membrane(controller = "primitive")
public class SysoutSenderImpl extends AbstractSenderImpl implements Sender {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(SysoutSenderImpl.class.getName());

	/**
	 * Default constructor
	 * 
	 * @throws CoreException
	 */
	public SysoutSenderImpl() {
		super();
	}

	public void sendTo(final InternalMessage<?> internalMessage,
			final Endpoint providerEndpoint, final ExternalContext context)
			throws CoreException {
		final ExternalMessage<?> externalMessage = this.messageConverter
				.createExternalMessageFromInternalMessage(internalMessage);
		if (externalMessage != null) {
			System.out.println("MESSAGE SENDED BY CORE: \n"
					+ externalMessage);
		} else {
			System.out.println("MESSAGE SENDED BY CORE: \n"
					+ externalMessage);
		}
	}

	public InternalMessage<?> sendSyncTo(final InternalMessage<?> message,
			final Endpoint providerEndpoint, final ExternalContext context)
			throws CoreException {
		final ExternalMessage<?> externalMessage = this.messageConverter
				.createExternalMessageFromInternalMessage(message);
		if (externalMessage != null) {
			System.out.println("MESSAGE SENDED BY CORE: \n"
					+ externalMessage);
		} else {
			System.out.println("MESSAGE SENDED BY CORE: \n"
					+ externalMessage);
		}

		final InternalMessage<?> internalMessage = this.messageConverter
				.createInternalMessageFromExternalMessage(externalMessage);
		if (internalMessage != null) {
			System.out.println("MESSAGE RECEIVED BY CORE: \n"
					+ internalMessage);
		} else {
			System.out.println("MESSAGE RECEIVED BY CORE: \n"
					+ internalMessage);
		}
		return internalMessage;
	}

	@Override
	public void setLog(final Logger logger) {
		super.setLog(logger);
		this.log = logger;
	}

	public void sendTo(CoreException e, ExternalContext context) {
		throw new UnsupportedOperationException();
	}
}

==> easyviper.core.impl-1.1-sources.jar: com/ebmwebsourcing/easyviper/tools/SysoutSenderImpl.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.tools;

import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.extensions.Membrane;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.env.ExternalContext;
import com.ebmwebsourcing.easyviper.core.api.env.Sender;
import com.ebmwebsourcing.easyviper.core.api.soa.Endpoint;
import com.ebmwebsourcing.easyviper.core.api.soa.message.ExternalMessage;
import com.ebmwebsourcing.easyviper.core.api.soa.message.InternalMessage;
import com.ebmwebsourcing.easyviper.core.impl.env.AbstractSenderImpl;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@org.objectweb.fractal.fraclet.annotations.Component
@Membrane(controller = "primitive")
public class SysoutSenderImpl extends AbstractSenderImpl implements Sender {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(SysoutSenderImpl.class.getName());

	/**
	 * Default constructor
	 * 
	 * @throws CoreException
	 */
	public SysoutSenderImpl() {
		super();
	}

	public void sendTo(final InternalMessage<?> internalMessage,
			final Endpoint providerEndpoint, final ExternalContext context)
			throws CoreException {
		final ExternalMessage<?> externalMessage = this.messageConverter
				.createExternalMessageFromInternalMessage(internalMessage);
		System.out.println("MESSAGE SENT BY CORE: \n"
				+ externalMessage);
	}

	public InternalMessage<?> sendSyncTo(final InternalMessage<?> message,
			final Endpoint providerEndpoint, final ExternalContext context)
			throws CoreException {
		final ExternalMessage<?> externalMessage = this.messageConverter
				.createExternalMessageFromInternalMessage(message);
		System.out.println("MESSAGE SENT BY CORE: \n"
				+ externalMessage);

		final InternalMessage<?> internalMessage = this.messageConverter
				.createInternalMessageFromExternalMessage(externalMessage);
		System.out.println("MESSAGE RECEIVED BY CORE: \n"
				+ internalMessage);
		return internalMessage;
	}

	@Override
	public void setLog(final Logger logger) {
		super.setLog(logger);
		this.log = logger;
	}

	public void sendTo(CoreException e, ExternalContext context) {
		throw new UnsupportedOperationException();
	}
}
